@@ -139,16 +139,22 @@ class APTPlugin(Plugin):
 
     def install(self, names):
         manual = []
-        default = []
+        targetted = {}
         for name in names:
-            if isinstance(name, dict):
+            if not isinstance(name, dict):
+                name = {"name": name}
+            if "path" in name:
                 manual.append(name)
             else:
-                if name in self._ignore():
+                if name["name"] in self._ignore():
                     logging.debug(f"Package {name} is part of the base system.")
-                default.append(name)
-        if default:
-            sudo().cc(["apt-get", "install", "-y"] + default)
+                targetted.setdefault(name.get("options") or {}, []).append(name)
+        for options, packages in targetted.items():
+            sudo().cc(
+                ["apt-get", "install", "-y"]
+                + options
+                + [package["name"] for package in packages]
+            )
         for package in manual:
             p = Path(package["path"]).expanduser()
             check_call([p / "build.sh"], cwd=p)
@@ -284,18 +290,15 @@ def main():
             add[plugin.id()] = [plugin_want[p] for p in plugin_want.keys() - installed]
             remove[plugin.id()] = installed - plugin_want.keys()
 
-        if args.dry_run:
-            print(
-                "\nPlan: Adding--\n{}".format(
-                    luxem.dumps(add, pretty=True).decode("utf-8")
-                )
+        print(
+            "\nPlan: Adding--\n{}".format(luxem.dumps(add, pretty=True).decode("utf-8"))
+        )
+        print(
+            "\nPlan: Removing--\n{}".format(
+                luxem.dumps(remove, pretty=True).decode("utf-8")
             )
-            print(
-                "\nPlan: Removing--\n{}".format(
-                    luxem.dumps(remove, pretty=True).decode("utf-8")
-                )
-            )
-        else:
+        )
+        if not args.dry_run:
             for plugin in plugins:
                 print(f"Installing packages for {plugin.id()}...")
                 plugin_add = list(add.get(plugin.id(), set()))
